@@ -11,7 +11,7 @@ def create_postgres_connection():
     username = os.getenv("POSTGRES_USER")
     password = os.getenv("POSTGRES_PASSWORD")
     hostname = os.getenv('POSTGRES_HOST', "localhost")
-    port = os.getenv("POSTGRES_PORT", "9020")
+    port = os.getenv("POSTGRES_PORT", "5432")
     db = os.getenv('POSTGRES_DB')
     engine = create_engine(
         f"postgresql+psycopg2://{username}:{password}@{hostname}:{port}/{db}")
@@ -19,5 +19,5 @@ def create_postgres_connection():
 
 
 def create_postgres_session(engine):
-    Session = sessionmaker(bind=engine)
+    Session = sessionmaker(bind=engine, expire_on_commit=False)
     return Session
